@@ -21,7 +21,7 @@ my $numeric_code = sub {
 };
 
 my $obj = Locale::Utils::PlaceholderNamed->new(
-    strict => 1,
+    is_strict => 1,
 );
 
 for my $value (undef, 0 .. 2, '345678.90', 45_678.90) { ## no critic (MagicNumbers)
@@ -33,7 +33,7 @@ for my $value (undef, 0 .. 2, '345678.90', 45_678.90) { ## no critic (MagicNumbe
     "\n";
 }
 
-$obj->strict(0);
+$obj->is_strict(0);
 
 for my $value (undef, 0 .. 2, '345678.90', 45_678.90) { ## no critic (MagicNumbers)
     () = print
