@@ -8,9 +8,9 @@ use MooX::StrictConstructor;
 use MooX::Types::MooseLike::Base qw(Bool CodeRef);
 use namespace::autoclean;
 
-our $VERSION = '0.006';
+our $VERSION = '1.000';
 
-has strict => (
+has is_strict => (
     is  => 'rw',
     isa => Bool,
 );
@@ -25,7 +25,7 @@ sub _mangle_value {
     my ($self, $placeholder, $value, $attribute) = @_;
 
     defined $value
-        or return $self->strict ? $placeholder : q{};
+        or return $self->is_strict ? $placeholder : q{};
     defined $attribute
         or return $value;
     $self->modifier_code
@@ -84,15 +84,15 @@ $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/Locale-Utils
 
 =head1 VERSION
 
-0.006
+1.000
 
 =head1 SYNOPSIS
 
     use Locale::Utils::PlaceholderNamed;
 
     my $obj = Locale::Utils::PlaceholderNamed->new(
-        # optional strict switch
-        strict => 1,
+        # optional is_strict switch
+        is_strict => 1,
         # optional modifier code
         modifier_code => sub {
             my ( $value, $attribute ) = @_;
@@ -114,12 +114,12 @@ Utils to expand named placeholders.
 
 =head1 SUBROUTINES/METHODS
 
-=head2 method strict
+=head2 method is_strict
 
-If strict is false: undef will be converted to q{}.
-If strict is true: no replacement.
+If is_strict is false: undef will be converted to q{}.
+If is_strict is true: no replacement.
 
-    $obj->strict(1); # boolean true or false;
+    $obj->is_strict(1); # boolean true or false;
 
 =head2 method modifier_code, clear_modifier_code
 
@@ -213,7 +213,7 @@ Steffen Winkler
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2011 - 2014,
+Copyright (c) 2011 - 2015,
 Steffen Winkler
 C<< <steffenw at cpan.org> >>.
 All rights reserved.
